==> MoarSigns-1.9-3.0.0-sources.jar: gory_moon/moarsigns/client/interfaces/containers/ContainerExchange.java <==
package gory_moon.moarsigns.client.interfaces.containers;

import gory_moon.moarsigns.client.interfaces.containers.slots.SlotInput;
import gory_moon.moarsigns.client.interfaces.containers.slots.SlotSelection;
import net.minecraft.entity.player.EntityPlayer;
import net.minecraft.entity.player.InventoryPlayer;
import net.minecraft.inventory.ClickType;
import net.minecraft.inventory.Container;
import net.minecraft.inventory.InventoryHelper;
import net.minecraft.inventory.Slot;
import net.minecraft.item.ItemStack;

public class ContainerExchange extends Container {

    public final InventoryExchange inventory;
    public InventoryPlayer playerInventory;
    public ItemStack itemToolBox;
    public boolean close;
    int toolBoxSlot;

    public ContainerExchange(InventoryPlayer inventoryPlayer, InventoryExchange exchangeInv) {
        inventory = exchangeInv;
        playerInventory = inventoryPlayer;
        toolBoxSlot = playerInventory.field_70461_c;
        exchangeInv.container = this;

        func_75146_a(new SlotInput(this, exchangeInv, 0, 22, 26));

        for (int y = 0; y < 3; y++) {
            for (int x = 0; x < 9; x++) {
                func_75146_a(new SlotSelection(this, exchangeInv, x + y * 9 + 1, 58 + 18 * x, 8 + y * 18));
            }
        }

        //Player inventory
        for (int x = 0; x < 9; x++) {
            func_75146_a(new Slot(inventoryPlayer, x, 40 + 18 * x, 138));
        }

        for (int y = 0; y < 3; y++) {
            for (int x = 0; x < 9; x++) {
                func_75146_a(new Slot(inventoryPlayer, x + y * 9 + 9, 40 + 18 * x, 80 + y * 18));
            }
        }

        itemToolBox = inventoryPlayer.func_70448_g();
        inventory.update();
    }

    public void onSlotChanged() {
        ItemStack stack = playerInventory.field_70462_a[toolBoxSlot];
        if (stack == null || !stack.func_77969_a(itemToolBox)) {
            close = true;
        }
    }

    @Override
    public ItemStack func_184996_a(int par1, int dragType, ClickType clickTypeIn, EntityPlayer player) {
        int clickedSlot = par1 - inventory.func_70302_i_();

        if (clickedSlot == toolBoxSlot || (dragType == 2 && par1 == toolBoxSlot)) {
            return null;
        }

        return super.func_184996_a(par1, dragType, clickTypeIn, player);
    }

    @Override
    public void func_75134_a(EntityPlayer player) {
        inventory.clearInventory();
        InventoryHelper.func_180176_a(player.field_70170_p, player, inventory);
        super.func_75134_a(player);
    }

    @Override
    public boolean func_75145_c(EntityPlayer player) {
        return inventory.func_70300_a(player);
    }

    @Override
    public ItemStack func_82846_b(EntityPlayer entity, int slotIdx) {
        ItemStack itemStack = null;
        Slot slot = (Slot) this.field_75151_b.get(slotIdx);

        if (slot != null && slot.func_75216_d()) {
            ItemStack itemStack1 = slot.func_75211_c();
            itemStack = itemStack1.func_77946_l();

            if (slotIdx > 27) {
                if (((Slot) this.field_75151_b.get(0)).func_75214_a(itemStack1)) {
                    if (!this.func_75135_a(itemStack1, 0, 1, false)) {
                        return null;
                    }
                }
            } else {
                if (slotIdx < 28) {
                    entity.field_71071_by.func_70437_b(itemStack1.func_77946_l());
                    slot.func_82870_a(entity, itemStack1);
                    itemStack1 = entity.field_71071_by.func_70445_o();
                    entity.field_71071_by.func_70437_b(null);
                }

                if (!this.func_75135_a(itemStack1, 28, 28 + 36, false)) {
                    return null;
                }
            }
            slot.func_75220_a(itemStack1, itemStack);

            if (itemStack1.field_77994_a == 0) {
                slot.func_75215_d(null);
            } else {
                slot.func_75218_e();
            }

            if (itemStack1.field_77994_a == itemStack.field_77994_a) {
                return null;
            }

            if (slotIdx > 28 || slotIdx == 0) {
                slot.func_82870_a(entity, itemStack1);
            }

            if (itemStack1.field_77994_a == 0) {
                slot.func_75215_d(null);
                return null;
            }
        }
        return itemStack;
    }
}

==> MoarSigns-1.10.2-4.0.1.4-sources.jar: gory_moon/moarsigns/client/interfaces/containers/ContainerExchange.java <==
package gory_moon.moarsigns.client.interfaces.containers;

import gory_moon.moarsigns.client.interfaces.containers.slots.SlotInput;
import gory_moon.moarsigns.client.interfaces.containers.slots.SlotSelection;
import net.minecraft.entity.player.EntityPlayer;
import net.minecraft.entity.player.InventoryPlayer;
import net.minecraft.inventory.ClickType;
import net.minecraft.inventory.Container;
import net.minecraft.inventory.InventoryHelper;
import net.minecraft.inventory.Slot;
import net.minecraft.item.ItemStack;

public class ContainerExchange extends Container {

    public final InventoryExchange inventory;
    public InventoryPlayer playerInventory;
    public ItemStack itemToolBox;
    public boolean close;
    int toolBoxSlot;

    public ContainerExchange(InventoryPlayer inventoryPlayer, InventoryExchange exchangeInv) {
        inventory = exchangeInv;
        playerInventory = inventoryPlayer;
        toolBoxSlot = playerInventory.field_70461_c;
        exchangeInv.container = this;

        func_75146_a(new SlotInput(this, exchangeInv, 0, 22, 26));

        for (int y = 0; y < 3; y++) {
            for (int x = 0; x < 9; x++) {
                func_75146_a(new SlotSelection(this, exchangeInv, x + y * 9 + 1, 58 + 18 * x, 8 + y * 18));
            }
        }

        //Player inventory
        for (int x = 0; x < 9; x++) {
            func_75146_a(new Slot(inventoryPlayer, x, 40 + 18 * x, 138));
        }

        for (int y = 0; y < 3; y++) {
            for (int x = 0; x < 9; x++) {
                func_75146_a(new Slot(inventoryPlayer, x + y * 9 + 9, 40 + 18 * x, 80 + y * 18));
            }
        }

        itemToolBox = inventoryPlayer.func_70448_g();
        inventory.update();
    }

    public void onSlotChanged() {
        ItemStack stack = playerInventory.field_70462_a[toolBoxSlot];
        if (stack == null || !stack.func_77969_a(itemToolBox)) {
            close = true;
        }
    }

    @Override
    public ItemStack func_184996_a(int slotId, int dragType, ClickType clickTypeIn, EntityPlayer player) {
        int clickedSlot = slotId - inventory.func_70302_i_();

        if (clickedSlot == toolBoxSlot || (dragType == 2 && slotId == toolBoxSlot)) {
            return null;
        }

        return super.func_184996_a(slotId, dragType, clickTypeIn, player);
    }

    @Override
    public void func_75134_a(EntityPlayer player) {
        inventory.clearInventory();
        InventoryHelper.func_180176_a(player.field_70170_p, player, inventory);
        super.func_75134_a(player);
    }

    @Override
    public boolean func_75145_c(EntityPlayer player) {
        return inventory.func_70300_a(player);
    }

    @Override
    public ItemStack func_82846_b(EntityPlayer entity, int slotIdx) {
        ItemStack itemStack = null;
        Slot slot = (Slot) this.field_75151_b.get(slotIdx);

        if (slot != null && slot.func_75216_d()) {
            ItemStack itemStack1 = slot.func_75211_c();
            itemStack = itemStack1.func_77946_l();

            if (slotIdx > 27) {
                if (((Slot) this.field_75151_b.get(0)).func_75214_a(itemStack1)) {
                    if (!this.func_75135_a(itemStack1, 0, 1, false)) {
                        return null;
                    }
                }
            } else {
                if (slotIdx < 28) {
                    entity.field_71071_by.func_70437_b(itemStack1.func_77946_l());
                    slot.func_82870_a(entity, itemStack1);
                    itemStack1 = entity.field_71071_by.func_70445_o();
                    entity.field_71071_by.func_70437_b(null);
                }

                if (!this.func_75135_a(itemStack1, 28, 28 + 36, false)) {
                    return null;
                }
            }
            slot.func_75220_a(itemStack1, itemStack);

            if (itemStack1.field_77994_a == 0) {
                slot.func_75215_d(null);
            } else {
                slot.func_75218_e();
            }

            if (itemStack1.field_77994_a == itemStack.field_77994_a) {
                return null;
            }

            if (slotIdx > 28 || slotIdx == 0) {
                slot.func_82870_a(entity, itemStack1);
            }

            if (itemStack1.field_77994_a == 0) {
                slot.func_75215_d(null);
                return null;
            }
        }
        return itemStack;
    }
}
